@@ -1,5 +1,5 @@
 import pkg_resources
 
 from .kombucha import load_kombucha
-from .visualization.utils import filter_otus, plot_umap
+from .utils import filter_otus, plot_umap
 from .visualization.umap_hdbscan import Embedding_Output
